doapfiend.cli

Package doapfiend :: Module cli |
[hide private]
[frames] | no frames]

# Module cli

source code

# cli.py

Command-line tool for querying, serializing and displaying DOAP

Author: Rob Cakebread <rob@doapspace.org>

License : BSD-2

Classes | [hide private]
| DoapFiend `DoapFiend` class

Functions | [hide private]
doapfiend_version() Print doapfiend version | source code
main() Let's do it. | source code

Variables | [hide private]
| __revision__ = ``'````'``